@@ -37,23 +37,17 @@ class DescribeBackupPoliciesRequest(RpcRequest):
 	def set_ResourceOwnerId(self,ResourceOwnerId):
 		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
 
-	def get_CurrentPage(self):
-		return self.get_query_params().get('CurrentPage')
-
-	def set_CurrentPage(self,CurrentPage):
-		self.add_query_param('CurrentPage',CurrentPage)
-
 	def get_SourceIp(self):
 		return self.get_query_params().get('SourceIp')
 
 	def set_SourceIp(self,SourceIp):
 		self.add_query_param('SourceIp',SourceIp)
 
-	def get_Name(self):
-		return self.get_query_params().get('Name')
+	def get_MachineRemark(self):
+		return self.get_query_params().get('MachineRemark')
 
-	def set_Name(self,Name):
-		self.add_query_param('Name',Name)
+	def set_MachineRemark(self,MachineRemark):
+		self.add_query_param('MachineRemark',MachineRemark)
 
 	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
@@ -61,6 +55,18 @@ class DescribeBackupPoliciesRequest(RpcRequest):
 	def set_PageSize(self,PageSize):
 		self.add_query_param('PageSize',PageSize)
 
+	def get_CurrentPage(self):
+		return self.get_query_params().get('CurrentPage')
+
+	def set_CurrentPage(self,CurrentPage):
+		self.add_query_param('CurrentPage',CurrentPage)
+
+	def get_Name(self):
+		return self.get_query_params().get('Name')
+
+	def set_Name(self,Name):
+		self.add_query_param('Name',Name)
+
 	def get_Status(self):
 		return self.get_query_params().get('Status')
 
