@@ -89,4 +89,10 @@ class DescribeSnapshotsRequest(RpcRequest):
 		return self.get_query_params().get('MachineRegion')
 
 	def set_MachineRegion(self,MachineRegion):
-		self.add_query_param('MachineRegion',MachineRegion)
\ No newline at end of file
+		self.add_query_param('MachineRegion',MachineRegion)
+
+	def get_IsAliYunEcs(self):
+		return self.get_query_params().get('IsAliYunEcs')
+
+	def set_IsAliYunEcs(self,IsAliYunEcs):
+		self.add_query_param('IsAliYunEcs',IsAliYunEcs)
\ No newline at end of file
