@@ -18,12 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdksas.endpoint import endpoint_data
 
 class ModifyOperateVulRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ModifyOperateVul','sas')
 		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_Reason(self):
 		return self.get_query_params().get('Reason')
@@ -37,14 +43,14 @@ class ModifyOperateVulRequest(RpcRequest):
 	def set_Type(self,Type):
 		self.add_query_param('Type',Type)
 
-	def get_OperateType(self):
-		return self.get_query_params().get('OperateType')
-
-	def set_OperateType(self,OperateType):
-		self.add_query_param('OperateType',OperateType)
-
 	def get_Info(self):
 		return self.get_query_params().get('Info')
 
 	def set_Info(self,Info):
-		self.add_query_param('Info',Info)
\ No newline at end of file
+		self.add_query_param('Info',Info)
+
+	def get_OperateType(self):
+		return self.get_query_params().get('OperateType')
+
+	def set_OperateType(self,OperateType):
+		self.add_query_param('OperateType',OperateType)
\ No newline at end of file
